getWebMetaAppId function
Returns the web app id from host page metadata when running on the web.
Non-web platforms do not expose browser metadata, so this stub always
returns null.
Implementation
String? getWebMetaAppId() => null;
Returns the web app id from host page metadata when running on the web.
Non-web platforms do not expose browser metadata, so this stub always
returns null.
String? getWebMetaAppId() => null;